/**
 * 检测是否为移动设备
 */
export const isMobileDevice = (): boolean => {
  // 检查用户代理字符串
  const userAgent = navigator.userAgent;
  const mobileKeywords = /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i;
  const isMobileUA = mobileKeywords.test(userAgent);
  
  // 检查屏幕尺寸
  const isSmallScreen = window.innerWidth <= 768;
  
  // 检查触摸支持
  const hasTouchSupport = 'ontouchstart' in window || navigator.maxTouchPoints > 0;
  
  return isMobileUA || (isSmallScreen && hasTouchSupport);
};

/**
 * 检测是否为平板设备
 */
export const isTabletDevice = (): boolean => {
  const userAgent = navigator.userAgent;
  const tabletKeywords = /iPad|Android(?!.*Mobile)/i;
  const isTabletUA = tabletKeywords.test(userAgent);
  
  const isMediumScreen = window.innerWidth > 768 && window.innerWidth <= 1024;
  
  return isTabletUA || isMediumScreen;
};

/**
 * 获取设备类型
 */
export const getDeviceType = (): 'mobile' | 'tablet' | 'desktop' => {
  if (isMobileDevice()) {
    return 'mobile';
  }
  if (isTabletDevice()) {
    return 'tablet';
  }
  return 'desktop';
};

/**
 * 获取推荐的路由路径
 */
export const getRecommendedRoute = (): string => {
  // 暂时让所有设备都重定向到移动端首页，方便测试
  return '/mobile/home';
  
  // 原来的逻辑保留备用
  // const deviceType = getDeviceType();
  // 
  // switch (deviceType) {
  //   case 'mobile':
  //   case 'tablet':
  //     return '/mobile/home';
  //   case 'desktop':
  //   default:
  //     return '/dashboard';
  // }
}; 